@@ -20,7 +20,6 @@ from typing import List, Type
 
 from google.protobuf import descriptor_pb2
 from google.protobuf import message
-from google.protobuf import symbol_database
 from google.protobuf.json_format import MessageToJson, Parse
 
 from proto import _file_info
@@ -156,7 +155,12 @@ class MessageMeta(type):
 
             # Same thing, but for enums.
             elif field.enum and not isinstance(field.enum, str):
-                field_enum = field.enum._meta.pb
+                field_enum = field.enum
+                field_enum = (
+                    field.enum._meta.pb
+                    if hasattr(field.enum, "_meta")
+                    else field.enum.DESCRIPTOR
+                )
 
                 if field_enum:
                     proto_imports.add(field_enum.file.name)
